@@ -1,5 +1,3 @@
-use crate::error::Error;
-
 #[derive(Copy, Clone, Debug, Default, PartialEq, Eq)]
 #[cfg_attr(test, derive(proptest_derive::Arbitrary))]
 pub struct ModelData {
@@ -9,16 +7,16 @@ pub struct ModelData {
 }
 
 impl ModelData {
-    pub fn to_bytes(self) -> [u8; 3] {
+    pub const fn to_bytes(self) -> [u8; 3] {
         [self.model, self.version, self.features]
     }
 
-    pub fn from_bytes(bytes: &[u8; 3]) -> Result<Self, Error> {
-        Ok(Self {
+    pub const fn from_bytes(bytes: [u8; 3]) -> Self {
+        Self {
             model: bytes[0],
             version: bytes[1],
             features: bytes[2],
-        })
+        }
     }
 }
 
@@ -31,7 +29,7 @@ mod test {
         #[test]
         fn model_data_from_to_bytes_roundtrip(model_data in any::<ModelData>()) {
             let bytes = model_data.to_bytes();
-            let decoded = ModelData::from_bytes(&bytes).unwrap();
+            let decoded = ModelData::from_bytes(bytes);
             assert_eq!(model_data, decoded);
         }
     }
