@@ -1,12 +1,12 @@
-use crate::error::Error;
+use super::Error;
 use smart_default::SmartDefault;
 
-#[cfg(feature = "param_fromstr")]
-use strum_macros::EnumString;
+#[cfg(feature = "arg_enum")]
+use clap::ArgEnum;
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq, SmartDefault)]
 #[cfg_attr(test, derive(proptest_derive::Arbitrary))]
-#[cfg_attr(feature = "param_fromstr", derive(EnumString))]
+#[cfg_attr(feature = "arg_enum", derive(ArgEnum))]
 pub enum AirBaudRate {
     Bps300,
     Bps1200,
