@@ -1,12 +1,12 @@
-use crate::error::Error;
+use crate::parameters::error::Error;
 use smart_default::SmartDefault;
 
-#[cfg(feature = "param_fromstr")]
-use strum_macros::EnumString;
+#[cfg(feature = "arg_enum")]
+use clap::ArgEnum;
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq, SmartDefault)]
 #[cfg_attr(test, derive(proptest_derive::Arbitrary))]
-#[cfg_attr(feature = "param_fromstr", derive(EnumString))]
+#[cfg_attr(feature = "arg_enum", derive(ArgEnum))]
 pub enum Parity {
     #[default]
     None,
@@ -15,7 +15,7 @@ pub enum Parity {
 }
 
 impl TryFrom<u8> for Parity {
-    type Error = super::Error;
+    type Error = Error;
 
     fn try_from(value: u8) -> Result<Self, Self::Error> {
         match value {
@@ -37,18 +37,17 @@ impl From<Parity> for u8 {
     }
 }
 
-#[cfg(feature = "param_fromstr")]
+#[cfg(feature = "arg_enum")]
 #[cfg(test)]
 mod test {
     use super::*;
-    use core::str::FromStr;
 
     #[test]
     fn parses_parity() {
-        let none = Parity::from_str("None").unwrap();
+        let none = Parity::from_str("None", true).unwrap();
         assert_eq!(none, Parity::None);
 
-        let even = Parity::from_str("Even").unwrap();
+        let even = Parity::from_str("Even", true).unwrap();
         assert_eq!(even, Parity::Even);
     }
 }
